package com.aliyun.tablestore.example.grid;

import com.alicloud.openservices.tablestore.model.search.sort.FieldSort;
import com.alicloud.openservices.tablestore.model.search.sort.Sort;
import com.alicloud.openservices.tablestore.model.search.sort.SortOrder;
import com.aliyun.tablestore.example.grid.common.ExampleConfig;
import com.aliyun.tablestore.example.grid.common.TableStoreGridExample;
import com.aliyun.tablestore.grid.core.QueryBuilder;
import com.aliyun.tablestore.grid.model.GridDataSetMeta;
import com.aliyun.tablestore.grid.model.QueryGridDataSetResult;
import com.aliyun.tablestore.grid.model.QueryParams;
import lombok.extern.slf4j.Slf4j;

import java.util.Collections;
import java.util.List;

@Slf4j
public class MetaDeleteExample extends TableStoreGridExample {
    public MetaDeleteExample() {
        super(ExampleConfig.GRID_DATA_TABLE_NAME, ExampleConfig.GRID_META_TABLE_NAME);
    }

    private List<GridDataSetMeta> query() throws Exception {
        QueryGridDataSetResult result = tableStoreGrid.queryDataSets(
                ExampleConfig.GRID_META_INDEX_NAME,
                QueryBuilder.or()
                        .equal("status", "DONE")
                        .equal("status", "INIT")
                        .build(),
                new QueryParams(0, 1000, new Sort(Collections.singletonList(new FieldSort("create_time", SortOrder.DESC)))));

        return result.getGridDataSetMetas();
    }

    private void batchDeleteRow() throws Exception {
        List<GridDataSetMeta> metaList = query();
        while (!metaList.isEmpty()) {
            for (GridDataSetMeta meta : metaList) {
                // 获取行的主键
                String gridDataSetId = meta.getGridDataSetId();
                if (!"test_echam_spectral_example".equals(gridDataSetId)) {
                    log.info("删除行：{}", gridDataSetId);
                    tableStoreGrid.deleteDataSetMeta(gridDataSetId);
                }
            }
            metaList = query();
        }
    }

    public static void main(String[] args) throws Exception {
        MetaDeleteExample example = new MetaDeleteExample();
        try {
            example.batchDeleteRow();
        } finally {
            example.close();
        }
    }
}
