package com.htfp.weather.download.gfs;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;

/**
 * @Author : shiyi
 * @Date : 2024/1/15 14:54
 * @Description : 文件气压坐标变量名和表中变量名的映射
 */
public enum GfsVariableIsobaricEnum {
    //
    TEMP("temp", "Temperature_isobaric"),
    RH("humidity", "Relative_humidity_isobaric"),
    CLOUD("cloud", "Total_cloud_cover_isobaric"),
    WIND_SPEED("windSpeed", "Wind_speed_isobaric"),
    WIND360("wind360", "Wind_direction_isobaric"),
    ;
    private static final ConcurrentHashMap<String, String> variableName = new ConcurrentHashMap<String, String>() {{
        put("temp", "Temperature_isobaric");
        put("cloud", "Total_cloud_cover_isobaric");
        put("windSpeed", "Wind_speed_isobaric");
        put("wind360", "Wind_direction_isobaric");
        put("humidity", "Relative_humidity_isobaric");
    }};
    String nameInApi;
    String nameInFile;

    GfsVariableIsobaricEnum(String nameInApi, String nameInFile) {
        this.nameInApi = nameInApi;
        this.nameInFile = nameInFile;
    }


    public String getNameInApi() {
        return nameInApi;
    }

    public String getNameInFile() {
        return nameInFile;
    }
    public static String getGfsVariableName(GfsVariableIsobaricEnum gfsVariableIsobaricEnum) {
        return variableName.get(gfsVariableIsobaricEnum.nameInApi);
    }
    public static String getGfsVariableName(String nameInApi) {
        return variableName.get(nameInApi);
    }

    public static String getVariableNameInApi(String nameInFile) {
        for (GfsVariableIsobaricEnum anEnum : values()) {
            if (anEnum.nameInFile.equals(nameInFile)) {
                return anEnum.nameInApi;
            }
        }
        return null;
    }

    public static List<String> getVariableNamesInApi() {
        return new ArrayList<>(variableName.keySet());
    }

    public static List<String> getVariableNamesInFile() {
        return new ArrayList<>(variableName.values());
    }
}
