package com.htfp.weather.griddata.operation;

import com.alicloud.openservices.tablestore.model.TableOptions;
import com.alicloud.openservices.tablestore.model.search.FieldSchema;
import com.alicloud.openservices.tablestore.model.search.FieldType;
import com.alicloud.openservices.tablestore.model.search.IndexSchema;
import com.aliyun.tablestore.grid.consts.AttributionEnum;
import com.htfp.weather.griddata.common.TableConfigStatic;


import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * @Author : shiyi
 * @Date : 2024/1/15 15:10
 * @Description : 创建表
 */
public class CreateTable extends BaseTableOperation {

    /**
     * we must create store before we can use it.
     * @throws Exception
     */
    private void createStore() throws Exception {
        TableOptions tableOptions = new TableOptions(TableConfigStatic.TIME_TO_LIVE, 1);
        this.tableStoreGrid.createStore(tableOptions);
    }

    /**
     * this example create an index which contains these columns: status, tag1, tag2, create_time.
     * you can create an index which contains any other columns.
     *
     * @throws Exception
     */
    private void createIndex() throws Exception {
        IndexSchema indexSchema = new IndexSchema();
        AttributionEnum[] values = AttributionEnum.values();
        ArrayList<FieldSchema> fieldSchemas = new ArrayList<>();
        for (AttributionEnum attributionEnum : values) {
            fieldSchemas.add(new FieldSchema(attributionEnum.getName(), attributionEnum.getType()).setIndex(true).setEnableSortAndAgg(true));
        }
        indexSchema.setFieldSchemas(fieldSchemas);
        this.tableStoreGrid.createMetaIndex(TableConfigStatic.META_INDEX_NAME, indexSchema);
    }

    public static void main(String[] args) throws Exception {
        TableConfigStatic.initDatasetConfig();
        CreateTable example = new CreateTable();
        example.init();
        try {
            example.createStore();
            example.createIndex();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            example.close();
        }
    }
}
