package com.htfp.weather.utils;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;

import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.Map;

public class JSONUtils {

    private final static ObjectMapper objectMapper = new ObjectMapper();

    private JSONUtils() {

    }

    public static ObjectMapper getInstance() {
        return objectMapper;
    }

    /**
     * javaBean,list,array convert to json string
     */
    public static String obj2json(Object obj) throws JsonProcessingException {
        return objectMapper.writeValueAsString(obj);
    }

    /**
     * json string convert to javaBean
     */
    public static <T> T json2obj(String jsonStr, Class<T> clazz) throws IOException {
        return objectMapper.readValue(jsonStr, clazz);
    }
    /**
     *     通用静态方法：将JSON字符串转换为带泛型的类, T嵌套了其他泛型
     */
    public static <T> T json2obj(String json, TypeReference<T> typeReference) throws IOException {
        return objectMapper.readValue(json, typeReference);
    }
    /**
     * json string convert to map
     */
    public static Map<String, Object> json2map(String jsonStr) throws IOException {
        return objectMapper.readValue(jsonStr, new TypeReference<Map<String, Object>>() {});
    }

    /**
     * JSON string convert to map with specific javaBean
     */
    public static <T> Map<String, T> json2map(String jsonStr, Class<T> clazz) throws IOException {
        JavaType type = objectMapper.getTypeFactory().constructMapType(Map.class, String.class, clazz);
        return objectMapper.readValue(jsonStr, type);
    }

    /**
     * json array string convert to list with specific javaBean
     */
    public static <T> List<T> json2list(String jsonArrayStr, Class<T> clazz)
            throws IOException {
        return objectMapper.readValue(
                jsonArrayStr,
                objectMapper.getTypeFactory().constructCollectionType(List.class, clazz)
        );
    }

    /**
     * map convert to javaBean
     */
    public static <T> T map2obj(Map<String, T> map, Class<T> clazz) {
        return objectMapper.convertValue(map, clazz);
    }

    public static void pojo2jsonFile(Object obj, String filePath) throws IOException {
        ObjectMapper objectMapper = new ObjectMapper();
        objectMapper.enable(SerializationFeature.INDENT_OUTPUT);
        objectMapper.writeValue(new File(filePath), obj);
    }
    public static void main(String[] args) throws Exception {

    }
}