package com.htfp.weather.utils.ssl;

import org.springframework.util.CollectionUtils;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLSession;
import java.util.Arrays;
import java.util.List;

public class SelectiveHostnameVerifier implements HostnameVerifier {
    private List<String> trustedDomains;
    private final HostnameVerifier defaultVerifier = HttpsURLConnection.getDefaultHostnameVerifier();

    public SelectiveHostnameVerifier(){}

    public SelectiveHostnameVerifier(List<String> trustedDomains) {
        this.trustedDomains = trustedDomains;
    }

    @Override
    public boolean verify(String hostname, SSLSession session) {
        if (!CollectionUtils.isEmpty(trustedDomains) && trustedDomains.contains(hostname)) {
            // 白名单域名：跳过主机名验证
            return true;
        } else {
            // 其他域名：使用默认验证
            return defaultVerifier.verify(hostname, session);
        }
    }
}
