package com.htfp.weather.utils.ssl;

import lombok.extern.slf4j.Slf4j;
import org.springframework.util.CollectionUtils;

import javax.net.ssl.TrustManagerFactory;
import javax.net.ssl.X509TrustManager;
import java.security.KeyStore;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.Arrays;
import java.util.List;

@Slf4j
public class SelectiveTrustManager implements X509TrustManager {
    // 目标域名白名单（如：example.com）
    private final List<String> trustedDomains;
    private final X509TrustManager defaultTrustManager;
    private final X509TrustManager fakeTrustManager;

    public SelectiveTrustManager(List<String> trustedDomains) throws Exception {
        this.trustedDomains = trustedDomains;
        // 获取默认 TrustManager
        TrustManagerFactory tmf = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
        tmf.init((KeyStore) null);
        defaultTrustManager = (X509TrustManager) tmf.getTrustManagers()[0];

        // 创建一个“信任所有证书”的 TrustManager（仅用于白名单域名）
        fakeTrustManager = new X509TrustManager() {
            @Override
            public void checkClientTrusted(X509Certificate[] chain, String authType) {
            }

            @Override
            public void checkServerTrusted(X509Certificate[] chain, String authType) {
            }

            @Override
            public X509Certificate[] getAcceptedIssuers() {
                return new X509Certificate[0];
            }
        };
    }

    @Override
    public void checkClientTrusted(X509Certificate[] chain, String authType) {
        // 客户端验证交给默认逻辑
        try {
            defaultTrustManager.checkClientTrusted(chain, authType);

        } catch (CertificateException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public void checkServerTrusted(X509Certificate[] chain, String authType) throws CertificateException {
        // 获取当前请求的域名
        String hostname = getCurrentHostname(); // 需要额外逻辑获取当前域名
        if (!CollectionUtils.isEmpty(trustedDomains) && trustedDomains.contains(hostname)) {
            // 白名单域名：跳过证书验证
            log.debug("{} is in trusted domains, skipping certificate verification", hostname);
            fakeTrustManager.checkServerTrusted(chain, authType);
        } else {
            // 非白名单域名：使用默认验证
            defaultTrustManager.checkServerTrusted(chain, authType);
        }
    }

    @Override
    public X509Certificate[] getAcceptedIssuers() {
        return defaultTrustManager.getAcceptedIssuers();
    }

    // 需要结合 OkHttp 拦截器或反射获取当前请求域名（见后续优化）
    private String getCurrentHostname() {
        return HostInterceptor.getCurrentHostname();
    }
}