package com.htfp.weather.web.controller;

import com.google.common.primitives.Ints;
import com.htfp.weather.griddata.common.TableConfig;
import com.htfp.weather.web.config.aspect.ControllerLog;
import com.htfp.weather.web.exception.ErrorCode;
import com.htfp.weather.web.param.response.LevelsAvailableResponse;
import com.htfp.weather.web.param.response.LevelsAvailableResponse.LevelsAvailable;
import com.htfp.weather.web.param.response.Result;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.*;

/**
 * @Author : shiyi
 * @Date : 2024/4/21 15:56
 * @Description : 配置文件管理
 */
@CrossOrigin
@RestController
@Slf4j
@RequestMapping("/htfp/weather/v1/info")
public class InfoController {
    @Resource
    TableConfig tableConfig;

    @PostMapping("/queryLevelsAvailable")
    @ControllerLog(info = "可选高度查询")
    public Result queryLevelsAvailable(Map<String, String> params) {
        String dataSource = params.get("dataSource");
        List<LevelsAvailable> levelsAvailableList = new ArrayList<>();
        if (StringUtils.isEmpty(dataSource)) {
            levelsAvailableList.add(
                    new LevelsAvailable(
                            "GFS",
                            Ints.asList(tableConfig.getPressureList()),
                            Ints.asList(tableConfig.getPressureHeightList()))
            );
        } else {
            if (dataSource.equals("GFS")) {
                levelsAvailableList = Collections.singletonList(
                        new LevelsAvailable(
                                "GFS",
                                Ints.asList(tableConfig.getPressureList()),
                                Ints.asList(tableConfig.getPressureHeightList()))
                );
            }
        }
        return Result.success(new LevelsAvailableResponse(levelsAvailableList));
    }
}
