package com.htfp.weather.web.controller;

import com.htfp.weather.web.config.aspect.ControllerLog;
import com.htfp.weather.web.exception.ErrorCode;
import com.htfp.weather.web.param.cma.CmaWarning;
import com.htfp.weather.web.param.request.Position2D;
import com.htfp.weather.web.param.response.NowWeatherStatus;
import com.htfp.weather.web.param.response.Result;
import com.htfp.weather.web.param.response.SurfaceWeatherWarning;
import com.htfp.weather.web.param.response.TimeSeriesDataset;
import com.htfp.weather.web.service.GfsDataServiceImpl;
import com.htfp.weather.web.service.surfaceapi.CaiYunServiceImpl;
import com.htfp.weather.web.service.surfaceapi.CmaServiceImpl;
import com.htfp.weather.web.service.surfaceapi.HeFengServiceImpl;
import com.htfp.weather.web.service.surfaceapi.ISurfaceDataService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.List;

/**
 * @Author : shiyi
 * @Date : 2024/1/24 16:07
 * @Description : 地面天气状态
 */
@CrossOrigin
@RestController
@Slf4j
@RequestMapping("/htfp/weather/v1/surface/")
public class SurfaceWeatherController {
    @Resource
    CmaServiceImpl cmaService;
    @Resource
    HeFengServiceImpl heFengService;
    @Resource
    CaiYunServiceImpl caiYunService;
    @Resource
    GfsDataServiceImpl gfsDataService;
    ISurfaceDataService service;
    @PostConstruct
    public void init() {
        service = gfsDataService;
    }

    public Result switchSurfaceDataSource(String dataSource) {
        switch (dataSource.toLowerCase()) {
            case "hefeng":
                service = heFengService;
                return Result.success();
            case "caiyun":
                service = caiYunService;
                return Result.success();
            default:
                return Result.error(ErrorCode.VALIDATE_ERROR, "未知数据源");
        }
    }

    @PostMapping("/querySurfaceNowWeather")
    @ControllerLog(info = "地面实时气象信息查询")
    public Result queryNowWeather(@Validated @RequestBody Position2D position2D) throws Exception {
        double lat = position2D.getLatitude();
        double lon = position2D.getLongitude();

        NowWeatherStatus nowWeatherStatus = service.getNowSurfaceWeatherStatus(lat, lon);
        nowWeatherStatus.setLatitude(lat);
        nowWeatherStatus.setLongitude(lon);
        nowWeatherStatus.setDataSource(service.getDataSource());
        return Result.success(nowWeatherStatus);
    }

    @PostMapping("/querySurfaceForecast")
    @ControllerLog(info = "地面24小时预报结果查询")
    public Result querySurfaceForecast(@Validated @RequestBody Position2D position2D) throws Exception {
        double lat = position2D.getLatitude();
        double lon = position2D.getLongitude();

        TimeSeriesDataset forecastSeries = service.getForecastSeries(lat, lon);
        forecastSeries.setLatitude(lat);
        forecastSeries.setLongitude(lon);
        forecastSeries.setDataSource(service.getDataSource());
        return Result.success(forecastSeries);
    }

    @PostMapping("/queryWeatherWarning")
    @ControllerLog(info = "地面气象预警信息查询")
    public Result queryWeatherWarning(@Validated @RequestBody Position2D position2D) throws Exception {
        double lat = position2D.getLatitude();
        double lon = position2D.getLongitude();

        // List<SurfaceWeatherWarning> warning = surfaceDataService.getSurfaceWarning(lat, lon);
        List<SurfaceWeatherWarning> warning = cmaService.getSurfaceWarning(lat, lon);
        return Result.success(warning);
    }

    @PostMapping("/queryAllWeatherWarning")
    @ControllerLog(info = "全国地面气象预警信息查询")
    public Result queryWeatherWarning() throws Exception {
        // List<SurfaceWeatherWarning> warning = surfaceDataService.getSurfaceWarning(lat, lon);
        List<CmaWarning> cmaWarningList = cmaService.getSurfaceWeatherWarnings(null);
        cmaService.updateCmaWarningCache(cmaWarningList);
        return Result.success(cmaWarningList);
    }
}
