package com.htfp.weather.web.param.request;

import com.htfp.weather.download.gfs.GfsVariableIsobaricEnum;
import com.htfp.weather.download.gfs.GfsLevelsEnum;
import com.htfp.weather.web.exception.AppException;
import com.htfp.weather.web.exception.ErrorCode;
import com.htfp.weather.web.valid.DateTimeStr;
import com.htfp.weather.web.valid.EnumValid;
import lombok.Data;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;

/**
 * @Author : shiyi
 * @Date : 2024/5/15 16:11
 * @Description : 平面数据请求体
 */
@Data
public class PlaneRequest {
    @NotNull(message = "时间不能为空")
    @DateTimeStr(message = "时间格式错误")
    String time;

    @NotNull(message = "变量名不能为空")
    @EnumValid(enumClass = GfsVariableIsobaricEnum.class, usedField = "getNameInApi", message = "变量不存在")
    String variableName;

    @NotNull(message = "高度层不能为空")
    @EnumValid(enumClass = GfsLevelsEnum.class, usedField = "getCode", message = "高度层不存在")
    Integer level;

    @NotNull
    @Min(value = 70, message = "经度最小值为70（东经180°）")
    @Max(value = 140, message = "经度最大值为140（东经140°）")
    private Double minLongitude;

    @NotNull
    @Min(value = 70, message = "经度最小值为70（东经180°）")
    @Max(value = 140, message = "经度最大值为140（东经140°）")
    private Double maxLongitude;

    @NotNull
    @Min(value = 0, message = "纬度最小值为0（0°）")
    @Max(value = 55, message = "纬度最大值为55（北纬55°）")
    private Double minLatitude;

    @NotNull
    @Min(value = 0, message = "纬度最小值为0（0°）")
    @Max(value = 55, message = "纬度最大值为55（北纬55°）")
    private Double maxLatitude;

    public void valid() {
        // TODO 2024/4/21: 校验
        if (minLongitude >= maxLongitude) {
            throw new AppException(ErrorCode.VALIDATE_ERROR, "最小经度必须小于最大经度");
        }
        if (minLatitude >= maxLatitude) {
            throw new AppException(ErrorCode.VALIDATE_ERROR, "最小纬度必须小于最大纬度度");
        }
    }
}
