package com.htfp.weather.web.param.request;

import com.htfp.weather.download.gfs.GfsVariableIsobaricEnum;
import com.htfp.weather.web.valid.DateTimeStr;
import com.htfp.weather.web.valid.EnumValid;
import lombok.Data;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;

/**
 * @Author : shiyi
 * @Date : 2024/5/10 17:27
 * @Description : 廓线数据请求
 */
@Data
public class ProfileRequest {
    @NotNull(message = "时间不能为空")
    @DateTimeStr(message = "时间格式错误")
    String time;
    @EnumValid(enumClass = GfsVariableIsobaricEnum.class, usedField = "getNameInApi", message = "变量不存在")
    String variableName;

    @NotNull(message = "纬度 (latitude) 不能为空")
    @Min(value = -90, message = "纬度 (latitude) 最小值为-90（南纬90°）")
    @Max(value = 90, message = "纬度 (latitude) 最大值为90（北纬90°）")
    double latitude;

    @NotNull(message = "经度 (longitude) 不能为空")
    @Min(value = -180, message = "经度 (longitude) 最小值为-180（西经180°）")
    @Max(value = 180, message = "经度 (longitude) 最大值为180（东经180°）")
    double longitude;
}
