package com.htfp.weather.web.service;

import com.htfp.weather.web.exception.AppException;
import com.htfp.weather.web.exception.ErrorCode;
import com.htfp.weather.web.param.response.FileInfo;
import org.apache.commons.io.FileUtils;
import org.springframework.stereotype.Component;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * @Author : shiyi
 * @Date : 2024/6/12 11:25
 * @Description : 本地文件管理
 */
@Component
public class FileService {

    public List<FileInfo>  getFileList(File dataDir){
        if (!dataDir.exists() || !dataDir.isDirectory()) {
            throw new AppException(ErrorCode.DATA_FILE_OR_DIR_NOT_EXISTS);
        }
        List<FileInfo> fileInfoList = new ArrayList<>();
        File[] files = dataDir.listFiles();
        if (files == null || files.length == 0) {
            return null;
        }
        for (File file : files) {
            String fileName = file.getName();
            if (fileName.endsWith("grib2") || fileName.endsWith("nc")) {
                FileInfo fileInfo = new FileInfo();
                fileInfo.setFilePath(file.getAbsolutePath());
                fileInfo.setFileName(fileName);
                fileInfo.setFileSize(file.length());
                fileInfoList.add(fileInfo);
            }
        }
        return fileInfoList;
    }

    public List<String> getSubDirList(File dataRoot){
        if (!dataRoot.exists() || !dataRoot.isDirectory()) {
            throw new AppException(ErrorCode.DATA_FILE_OR_DIR_NOT_EXISTS);
        }
        List<String> subDirList = new ArrayList<>();
        File[] files = dataRoot.listFiles();
        if (files == null || files.length == 0) {
            return null;
        }
        for (File file : files) {
            if (file.isDirectory()) {
               subDirList.add(file.getName());
            }
        }
        return subDirList;
    }


    public void deleteFile(File file) throws IOException {
        if (file == null || !file.exists()) {
            throw new AppException(ErrorCode.DATA_FILE_OR_DIR_NOT_EXISTS);
        }
        FileUtils.delete(file);
    }

    public void deleteDir(File dir) throws IOException {
        if (!dir.exists() || !dir.isDirectory()) {
            throw new AppException(ErrorCode.DATA_FILE_OR_DIR_NOT_EXISTS);
        }
        FileUtils.deleteDirectory(dir);
    }
}
