package com.htfp.weather.utils;

import com.htfp.weather.web.param.hefeng.HeFengForecastResponse;
import com.htfp.weather.web.param.hefeng.HeFengNowResponse;
import lombok.extern.slf4j.Slf4j;
import org.junit.jupiter.api.Test;

import java.io.IOException;
import java.util.HashMap;

import static org.junit.jupiter.api.Assertions.assertThrows;


/**
 * @Author : shiyi
 * @Date : 2024/1/23 17:11
 * @Description :
 */
@Slf4j
class HttpClientUtilsTest {
    String key = "4df66bb82da04b5bb85624874209fc73";
    double lon = 116.4074;
    double lat = 39.9042;

    @Test
    public void sendGetTest1() throws Exception {
        String url = "https://devapi.qweather.com/v7/grid-weather/now";
        String location = String.format("%.2f,%.2f", lon, lat);
        HashMap<String, String> params = new HashMap<>();
        params.put("location", location);
        params.put("key", key);
        HeFengNowResponse heFengNowResponse = HttpClientUtils.sendGet(url, params, HeFengNowResponse.class);
        if (heFengNowResponse == null || !heFengNowResponse.getCode().startsWith("2")){
            log.error("请求失败");
            return;
        }
        System.out.println(heFengNowResponse.getNow());
    }

    @Test
    public void sendGetTest2() throws Exception {
        // 权限错误
        String url = "https://devapi.qweather.com/v7/grid-weather/24h";
        String location = String.format("%.2f,%.2f", lon, lat);
        HashMap<String, String> params = new HashMap<>();
        params.put("location", location);
        params.put("key", key);
        HeFengForecastResponse response = HttpClientUtils.sendGet(url, params, HeFengForecastResponse.class);
        if (response == null || !response.getCode().startsWith("2")){
            log.error("请求失败");
            return;
        }
        System.out.println(response.getHourly());
    }

    @Test
    public void sendGetTest3() throws IOException {
        // 参数错误
        String format = "https://devapi.qweather.com/v7/grid-weather/now";
        String url = String.format(format, lon, lat, key);
        String location = String.format("%.2f,%.2f", lon, lat);
        HashMap<String, String> params = new HashMap<>();
        params.put("location", location);
        params.put("key", key);
        System.out.println(HttpClientUtils.sendGet(url, params));
    }

    @Test
    public void sendGetTest4() throws Exception {
        // 参数错误
        String format = "https://devapi.qweather.com/v7/grid-weather/now";
        String url = String.format(format, lon, lat, key);
        String location = String.format("%.2f,%.2f", lon, lat);
        HashMap<String, String> params = new HashMap<>();
        params.put("location", location);
        params.put("key", key);
        String jsonStr = HttpClientUtils.sendGet(url, params);
        System.out.println(JSONUtils.json2obj(jsonStr, HeFengNowResponse.class));
        // assertThrows(IOException.class, ()->{HttpClientUtils.sendGet(url, params);});
    }

    @Test
    public void sendGetTest5() throws Exception {
        // 参数错误
        String url =  "http://localhost:10323/htfp/weather/index";
        HashMap<String, String> params = new HashMap<>();
        params.put("lat", "33.3");
        params.put("lon", "127.1");
        System.out.println(HttpClientUtils.sendGet(url, params, HeFengNowResponse.class));
    }
}